pub struct AppGuardIpInfo {
pub ip: String,
pub country: Option<String>,
pub asn: Option<String>,
pub org: Option<String>,
pub continent_code: Option<String>,
pub city: Option<String>,
pub region: Option<String>,
pub postal: Option<String>,
pub timezone: Option<String>,
pub blacklist: bool,
}Fields
ip: Stringcountry: Option<String>asn: Option<String>org: Option<String>continent_code: Option<String>city: Option<String>region: Option<String>postal: Option<String>timezone: Option<String>blacklist: boolImplementations
Sourceimpl AppGuardIpInfo
impl AppGuardIpInfo
Sourcepub fn country(&self) -> &str
pub fn country(&self) -> &str
Returns the value of country, or the default value if country is unset.
Sourcepub fn continent_code(&self) -> &str
pub fn continent_code(&self) -> &str
Returns the value of continent_code, or the default value if continent_code is unset.
Sourcepub fn region(&self) -> &str
pub fn region(&self) -> &str
Returns the value of region, or the default value if region is unset.